spoon.ber

Package spoon :: Package ber |
[show private | hide private]
[frames | no frames]

## Package spoon.ber

The low level BER based encoding used by spoon to serialize objects.

Users of the spoon library will probably not need to use this package at all.

Submodules
`common` `stream` `tag`

Function Summary
| ``decode`(s)` Decode a python object from a ber-encoded string and return it.
| ``decode_stream`(fd)` Decode a ber-encoded python object from a file object and return it.
| ``encode`(*items)` Encode one or more python objects into a ber stream, and return the encoded string.
| ``encode_stream`(fd, *items)` Encode one or more python objects into a ber stream, written to the given file object.

Function Details

### decode(s) Decode a python object from a ber-encoded string and return it.

### decode_stream(fd) Decode a ber-encoded python object from a file object and return it.

### encode(*items) Encode one or more python objects into a ber stream, and return the encoded string.

### encode_stream(fd, *items) Encode one or more python objects into a ber stream, written to the given file object.

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net